#ifndef COEM_H
#define COEM_H

#include <gsl/gsl_matrix.h>

#include "mixture.h"

typedef struct coem {
  unsigned int    maxiter;
  double          treshold;
  int             verbose;
  double          error;
  unsigned int    iter;
  double          ll;

  char*           mask;
  mixture**       mixtures;
  double**        weights;
  param**         components;
  param**         tmp_params;
  gsl_matrix**    posteriors;

  family*         ef;
  unsigned int    k;
  double**        data;
  unsigned int*   n;
  unsigned int    n_max;
  unsigned int    n_total;
  unsigned int    s;
  double          old_error;
  int             has_changed;
} coem;

coem* coem_create(family*       ef,
                  unsigned int  k,
                  unsigned int  s,
                  double**      data,
                  unsigned int* n
                  );
void coem_initialize_from_coclustering(coem* coem, double** weights, unsigned int** affectation);
void coem_aggregate(coem* coem, param** src, param* dest);
void coem_step(coem* coem);
mixture** coem_run(coem* coem);
void coem_destroy(coem* coem);

#endif
